import _ from 'lodash';

type RuleResult = number | false | undefined;

export const getMinimumRuleOutput = async <T>(
  rules: ((input: T) => RuleResult | Promise<RuleResult>)[],
  input: T,
) => {
  const results = await Promise.all(
    rules.map(async (rule) => {
      const result = await rule(input);
      if (result === undefined || result === false) {
        return null;
      }

      return { commission: result };
    }),
  );
  return Math.min(..._.compact(results).map(({ commission }) => commission));
};
